@@ -25,6 +25,7 @@ supported_sensors = {
     "pleiades": {
         "blocks": [
             "oneatlas-pleiades-fullscene",
+            "oneatlas-pleiades-display",
             "oneatlas-pleiades-aoiclipped",
         ],
         "provider": "oneatlas",
@@ -32,6 +33,7 @@ supported_sensors = {
     "spot": {
         "blocks": [
             "oneatlas-spot-fullscene",
+            "oneatlas-spot-display",
             "oneatlas-spot-aoiclipped",
         ],
         "provider": "oneatlas",
@@ -62,12 +64,18 @@ supported_sensors = {
 
 # pylint: disable=duplicate-code
 class Catalog(VizTools, Tools):
+    """
+    The Catalog class enables access to the UP42 catalog search. You can search
+    for satellite image scenes (for different sensors and criteria like cloud cover),
+    plot the scene coverage and download and plot the scene quicklooks.
+
+    Use the catalog:
+    ```python
+    catalog = up42.initialize_catalog()
+    ```
+    """
+
     def __init__(self, auth: Auth):
-        """
-        The Catalog class enables access to the UP42 catalog search. You can search
-        for satellite image scenes (for different sensors and criteria like cloud cover),
-        plot the scene coverage and download and plot the scene quicklooks.
-        """
         self.auth = auth
         self.quicklooks = None
 
@@ -203,19 +211,6 @@ class Catalog(VizTools, Tools):
         poly = shape(geometry)
         df = df[df.intersects(poly)]
         df = df.reset_index(drop=True)
-
-        # Make scene_id more easily accessible
-        def _get_scene_id(row):
-            if row["providerName"] == "oneatlas":
-                row["scene_id"] = row["providerProperties"]["parentIdentifier"]
-            elif row["providerName"] in ["sobloo-radar", "sobloo-image"]:
-                row["scene_id"] = row["providerProperties"]["identification"][
-                    "externalId"
-                ]
-            return row
-
-        # Search result dataframe can contain scenes of multiple sensors, need to apply row by row.
-        df = df.apply(_get_scene_id, axis=1)
         df.crs = dst_crs  # apply resets the crs
 
         if as_dataframe:
@@ -380,7 +375,7 @@ class Catalog(VizTools, Tools):
             scene (Series): A single item/row of the result of `Catalog.search`. For instance, search_results.loc[0]
                 for the first scene of a catalog search result.
             track_status (bool): If set to True, will only return the Order once it is `FULFILLED` or `FAILED`.
-            report_time (int): The intervall (in seconds) when to get the order status, 
+            report_time (int): The intervall (in seconds) when to get the order status,
                 if `track_status` is set to True.
 
          Warning:
