@@ -1,3 +1,6 @@
+"""
+Command Line Interface functionality with click
+"""
 import os
 import json
 from pathlib import Path
@@ -156,7 +159,7 @@ def blocks_from_context():
     class OptionChoiceFromContext(click.Option):
         def full_process_value(self, ctx, value):
             self.type = click.Choice(Tools(ctx.obj).get_blocks().keys())
-            return super(OptionChoiceFromContext, self).full_process_value(ctx, value)
+            return super().full_process_value(ctx, value)
 
     return OptionChoiceFromContext
 
@@ -271,7 +274,7 @@ def workflows_from_context():
         def full_process_value(self, ctx, value):
             workflow_names = [wkf._info["name"] for wkf in ctx.obj.get_workflows()]
             self.type = click.Choice(workflow_names)
-            return super(OptionChoiceFromContext, self).full_process_value(ctx, value)
+            return super().full_process_value(ctx, value)
 
     return OptionChoiceFromContext
 
